==> plugin-android-3.1.2-sources.jar: com/zoyi/channel/plugin/android/model/rest/Plugin.java <==
package com.zoyi.channel.plugin.android.model.rest;

import android.graphics.Color;
import android.support.annotation.ColorInt;

import com.zoyi.channel.plugin.android.model.interfaces.ProfileEntity;

import java.util.List;

/**
 * Created by mika on 2016. 12. 6..
 */
public class Plugin implements ProfileEntity {
  private String id;
  private String key;
  private String channelId;
  private String name;
  private Long createdAt;
  private String color;
  private String text;
  private I18n textI18n;
  private I18n welcomeNamedI18n;
  private I18n welcomeI18n;
  private I18n profileBotMessageI18n;
  private List<String> profileBotSchemaIds;
  private Boolean mobileHideButton;
  private String image;
  private String borderColor;
  private String textColor;
  private String botName;

  @Override
  public String getId() {
    return id;
  }

  public final static String CLASSNAME = "Plugin";

  @Override
  public String getName() {
    return name;
  }

  @Override
  public String getPersonType() {
    return null;
  }

  @Override
  @ColorInt
  public int getBackgroundColor() {
    try {
      return Color.parseColor(color);
    } catch (Exception ex) {
    }
    return Color.BLACK;
  }

  @ColorInt
  public int getTextColor() {
    return "black".equals(textColor) ? Color.BLACK : Color.WHITE;
  }

  @Override
  public String getAvatarUrl() {
    return null;
  }

  @Override
  public String getInitial() {
    return null;
  }

  public String getBorderColor() {
    return borderColor;
  }

  public String getBotName() {
    return botName;
  }

  public Boolean isHideLauncher() {
    return mobileHideButton;
  }

  public I18n getTextI18n() {
    return textI18n;
  }

  public I18n getWelcomeNamedI18n() {
    return welcomeNamedI18n;
  }

  public I18n getWelcomeI18n() {
    return welcomeI18n;
  }

  public I18n getProfileBotMessageI18n() {
    return profileBotMessageI18n;
  }

  public List<String> getProfileBotSchemaIds() {
    return profileBotSchemaIds;
  }
}

==> plugin-android-6.1.6-sources.jar: com/zoyi/channel/plugin/android/model/rest/Plugin.java <==
package com.zoyi.channel.plugin.android.model.rest;

import android.graphics.Color;
import android.support.annotation.ColorInt;

import com.zoyi.channel.plugin.android.model.entity.Entity;

/**
 * Created by mika on 2016. 12. 6..
 */
public class Plugin implements Entity {

  private String id;
  private String key;
  private String color;
  private I18n welcomeNamedI18n;
  private I18n welcomeI18n;
  private Boolean mobileHideButton;
  private String borderColor;
  private String textColor;
  private String gradientColor;
  private Boolean showPoweredBy;

  @Override
  public String getId() {
    return id;
  }

  public String getKey() {
    return key;
  }

  public String getPersonType() {
    return null;
  }

  @ColorInt
  public int getBackgroundColor() {
    try {
      return Color.parseColor(color);
    } catch (Exception ex) {
    }
    return Color.BLACK;
  }

  @ColorInt
  public int getTextColor() {
    return "black".equals(textColor) ? Color.BLACK : Color.WHITE;
  }

  public String getBorderColor() {
    return borderColor;
  }

  public int getGradientColor() {
    try {
      return Color.parseColor(gradientColor);
    } catch (Exception ex) {
    }
    return Color.BLACK;
  }

  public Boolean isHideLauncher() {
    return mobileHideButton;
  }

  public I18n getWelcomeNamedI18n() {
    return welcomeNamedI18n;
  }

  public I18n getWelcomeI18n() {
    return welcomeI18n;
  }

  public boolean isShowPoweredBy() {
    if (showPoweredBy == null) {
      return false;
    }
    return showPoweredBy;
  }
}
